@@ -362,7 +362,7 @@ void gf_sg_mffloat_del(MFFloat par);
 void gf_sg_mfdouble_del(MFDouble par);
 void gf_sg_mfbool_del(MFBool par);
 void gf_sg_mfcolor_del(MFColor par);
-void gf_sg_mfcolor_rgba_del(MFColorRGBA par);
+void gf_sg_mfcolorrgba_del(MFColorRGBA par);
 void gf_sg_mfrotation_del(MFRotation par);
 void gf_sg_mfstring_del(MFString par);
 void gf_sg_mftime_del(MFTime par);
@@ -376,6 +376,7 @@ void gf_sg_sfstring_del(SFString par);
 void gf_sg_mfscript_del(MFScript sc);
 void gf_sg_sfcommand_del(SFCommandBuffer cb);
 void gf_sg_sfurl_del(SFURL url);
+	void gf_sg_mfattrref_del(MFAttrRef par);
 
 Bool gf_sg_vrml_node_init(GF_Node *node);
 Bool gf_sg_vrml_node_changed(GF_Node *node, GF_FieldInfo *field);
